Documentation
¶
Overview ¶
Package brograb provides access to browser data. The main goal of the module is to provide a Cross-Platform access to browser data such as: passwords and cookies from all the common browsers.
Index ¶
Constants ¶
This section is empty.
Variables ¶
var (
BadDestFile = errors.New("bad destination type")
)
Functions ¶
This section is empty.
Types ¶
type Grabber ¶
type Grabber interface {
// Next prepares the next fetch data for reading with the Scan method. It
// returns true on success, or false if there is no next result row or an error
// happened while preparing it. Err should be consulted to distinguish between
// the two cases.
//
// Every call to Scan, even the first one, must be preceded by a call to Next.
Next() bool
// Scan copies the current fetched data into the interface pointed at
// by dest.
Scan(dest interface{}) error
// Err returns the error, if any, that was encountered during iteration.
Err() error
// Close stops the iteration, and closes all open databases, connections,
// and files used to fetch the browser data.
Close() error
}
Grabber is a basic data grabbing interface. Use Next and Scan to fetch the next grabbing data.
Directories
¶
| Path | Synopsis |
|---|---|
|
Package bookmarks lets you fetch saved bookmarks from all common browsers databases.
|
Package bookmarks lets you fetch saved bookmarks from all common browsers databases. |
|
Package browserutils implements utility functions to help with the brograb package.
|
Package browserutils implements utility functions to help with the brograb package. |
|
Package history lets you fetch history data from all common browsers databases.
|
Package history lets you fetch history data from all common browsers databases. |
|
Package passwords lets you fetch passwords from all common browsers databases.
|
Package passwords lets you fetch passwords from all common browsers databases. |
Click to show internal directories.
Click to hide internal directories.