browserutils

package
v0.3.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 7, 2021 License: MIT Imports: 2 Imported by: 0

Documentation

Overview

Package browserutils implements utility functions to help with the brograb package.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func FormatChromiumEpoch

func FormatChromiumEpoch(epoch int64) time.Time

FormatChromiumEpoch format the epoch from the chromium db, to a human readable format.

Types

type ProfileDir

type ProfileDir string

ProfileDir represents a profile directory of specific profile on chromium based systems.

func GetChromiumProfileDirs

func GetChromiumProfileDirs() ([]ProfileDir, error)

GetChromiumProfileDirs returns all the available Chromium profiles directories in the computer. With the list of profile directories you will be able to create new Grabbers such as PasswordGrabber etc.

func (ProfileDir) BookmarksDB

func (p ProfileDir) BookmarksDB() string

HistoryDB returns the path to the bookmarks database.

func (ProfileDir) CookiesDB

func (p ProfileDir) CookiesDB() string

HistoryDB returns the path to the cookies database.

func (ProfileDir) CreditCardsDB

func (p ProfileDir) CreditCardsDB() string

CreditCardsDB returns the path to the chromium database containing the saved credit cards.

func (ProfileDir) HistoryDB

func (p ProfileDir) HistoryDB() string

HistoryDB returns the path to the history database.

func (ProfileDir) Name

func (p ProfileDir) Name() string

Name returns the name of the profile directory.

Note: In case of multiply users in the system, the Name still could be the same. (Usually: Default)

func (ProfileDir) PasswordsDB

func (p ProfileDir) PasswordsDB() string

PasswordsDB returns the path to the chromium database containing the login data.

func (ProfileDir) Path

func (p ProfileDir) Path() string

Path returns the path of the profile directory.

Jump to